==> acornlib-1.21.1-r8-sources.jar: net/acoyt/acornlib/impl/mixin/ItemEntityMixin.java <==
package net.acoyt.acornlib.impl.mixin;

import net.acoyt.acornlib.impl.init.AcornComponents;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1542.class)
public abstract class ItemEntityMixin extends class_1297 {
    @Shadow public abstract class_1799 getStack();

    @Shadow @Nullable public abstract class_1297 getOwner();

    public ItemEntityMixin(class_1299<?> type, class_1937 world) {
        super(type, world);
    }

    @Inject(
            method = "tick",
            at = @At("HEAD")
    )
    public void tick(CallbackInfo ci) {
        class_1799 stack = this.getStack();
        class_1297 owner = this.getOwner();
        if (stack.method_57826(AcornComponents.UNDROPPABLE)) {
            if (!this.method_37908().field_9236 && owner instanceof class_1657 player) {
                player.method_7270(stack);
                this.method_5768();
            }
        }
    }

    @Inject(
            method = "cannotPickup",
            at = @At("RETURN"),
            cancellable = true
    )
    public void cannotPickup(CallbackInfoReturnable<Boolean> cir) {
        if (this.getStack().method_57826(AcornComponents.UNDROPPABLE)) {
            cir.setReturnValue(false);
        }
    }
}

==> acornlib-1.21.5-r19-sources.jar: net/acoyt/acornlib/impl/mixin/ItemEntityMixin.java <==
package net.acoyt.acornlib.impl.mixin;

import net.acoyt.acornlib.impl.index.AcornComponents;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1542.class)
public abstract class ItemEntityMixin extends class_1297 {
    @Shadow public abstract class_1799 getStack();

    @Shadow @Nullable public abstract class_1297 getOwner();

    public ItemEntityMixin(class_1299<?> type, class_1937 world) {
        super(type, world);
    }

    @Inject(
            method = "tick",
            at = @At("HEAD")
    )
    public void tick(CallbackInfo ci) {
        class_1799 stack = this.getStack();
        class_1297 owner = this.getOwner();
        if (stack.method_57826(AcornComponents.UNDROPPABLE)) {
            if (!this.method_37908().field_9236 && owner instanceof class_1657 player) {
                player.method_7270(stack);
                this.method_5768(this.method_5682().method_3847(this.method_37908().method_27983()));
            }
        }
    }

    @Inject(
            method = "cannotPickup",
            at = @At("RETURN"),
            cancellable = true
    )
    public void cannotPickup(CallbackInfoReturnable<Boolean> cir) {
        if (this.getStack().method_57826(AcornComponents.UNDROPPABLE)) {
            cir.setReturnValue(false);
        }
    }
}
